<?php    
/**
 * dashing functions and definitions
 *
 * @package Dashing
 */

// Set the word limit of post content 
function dashing_content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('dashing_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}
 

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'dashing_setup' ) ) : 
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function dashing_setup() {
	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'dashing', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support('woocommerce');
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'title-tag' );
	add_image_size('homepage-thumb',570,380,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'dashing' ),
		'footer' => __( 'Footer Menu', 'dashing' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
} 
endif; // dashing_setup
add_action( 'after_setup_theme', 'dashing_setup' );


function dashing_widgets_init() { 	
	
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'dashing' ),
		'description'   => __( 'Appears on blog page sidebar', 'dashing' ),
		'id'            => 'sidebar-1',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
	) );	
	
}
add_action( 'widgets_init', 'dashing_widgets_init' );


function dashing_font_url(){
		$font_url = '';		
		
		/* Translators: If there are any character that are not
		* supported by Montserrat, trsnalate this to off, do not
		* translate into your own language.
		*/
		$montserrat = _x('on','montserrat:on or off','dashing');		
		
		
		/* Translators: If there has any character that are not supported 
		*  by Scada, translate this to off, do not translate
		*  into your own language.
		*/
		$scada = _x('on','Scada:on or off','dashing');	
		
		if('off' !== $montserrat ){
			$font_family = array();
			
			if('off' !== $montserrat){
				$font_family[] = 'Montserrat:300,400,600,700,800,900';
			}
					
						
			$query_args = array(
				'family'	=> urlencode(implode('|',$font_family)),
			);
			
			$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
		}
		
	return $font_url;
	}


function dashing_scripts() {
	wp_enqueue_style('dashing-font', dashing_font_url(), array());
	wp_enqueue_style( 'dashing-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'dashing-editor-style', get_template_directory_uri()."/editor-style.css" );
	wp_enqueue_style( 'nivo-slider', get_template_directory_uri()."/css/nivo-slider.css" );
	wp_enqueue_style( 'dashing-main-style', get_template_directory_uri()."/css/responsive.css" );		
	wp_enqueue_style( 'dashing-base-style', get_template_directory_uri()."/css/style_base.css" );
	wp_enqueue_script( 'jquery-nivo', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'dashing-custom-js', get_template_directory_uri() . '/js/custom.js' );	
	wp_enqueue_style( 'dashing-font-awesome-style', get_template_directory_uri()."/css/font-awesome.css" );
		

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'dashing_scripts' );

function dashing_ie_stylesheet(){
	global $wp_styles;
	
	/** Load our IE-only stylesheet for all versions of IE.
	*   <!--[if lt IE 9]> ... <![endif]-->
	*
	*  Note: It is also possible to just check and see if the $is_IE global in WordPress is set to true before
	*  calling the wp_enqueue_style() function. If you are trying to load a stylesheet for all browsers
	*  EXCEPT for IE, then you would HAVE to check the $is_IE global since WordPress doesn't have a way to
	*  properly handle non-IE conditional comments.
	*/
	wp_enqueue_style('dashing_ie', get_template_directory_uri().'/css/ie.css', array('dashing_style'));
	$wp_styles->add_data('dashing_ie','conditional','IE');
	}
add_action('wp_enqueue_scripts','dashing_ie_stylesheet');


define('MRR_URL','http://www.mirrorthemes.com/','dashing');
define('MRR_PRO_THEME_URL','http://mirrorthemes.com/themes/dashing-multipurpose-wordpress-theme/','dashing');
define('MRR_THEME_DOC','http://www.mirrorthemes.com/documentation/dashing/','dashing');
define('MRR_LIVE_DEMO','http://mirrorthemes.com/demo/dashing/','dashing');
define('MRR_THEMES','http://www.mirrorthemes.com/themes/','dashing');

function dashing_designbytext(){
		return "Design by <a href=".esc_url(MRR_URL)." target='_blank'>Mirror Themes</a>";
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template for about theme.
 */
require get_template_directory() . '/inc/about-themes.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


// get slug by id
function dashing_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}